@@ -1,7 +1,7 @@
 /*
  * ip_vs_app.c: Application module support for IPVS
  *
- * Version:     $Id: ip_vs_app.c,v 1.16 2002/11/30 01:50:35 wensong Exp $
+ * Version:     $Id: ip_vs_app.c,v 1.17 2003/03/22 06:31:21 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -53,9 +53,9 @@ static DECLARE_MUTEX(__ip_vs_app_mutex);
  */
 static inline int ip_vs_app_get(struct ip_vs_app *app)
 {
-	/* test and MOD_INC_USE_COUNT atomically */
+	/* test and get the module atomically */
 	if (app->module)
-		return try_inc_mod_count(app->module);
+		return try_module_get(app->module);
 	else
 		return 1;
 }
@@ -64,7 +64,7 @@ static inline int ip_vs_app_get(struct ip_vs_app *app)
 static inline void ip_vs_app_put(struct ip_vs_app *app)
 {
 	if (app->module)
-		__MOD_DEC_USE_COUNT(app->module);
+		module_put(app->module);
 }
 
 
@@ -195,7 +195,8 @@ register_ip_vs_app_inc(struct ip_vs_app *app, __u16 proto, __u16 port)
  */
 int register_ip_vs_app(struct ip_vs_app *app)
 {
-	MOD_INC_USE_COUNT;
+	/* increase the module use count */
+	ip_vs_use_count_inc();
 
 	down(&__ip_vs_app_mutex);
 
@@ -227,7 +228,8 @@ void unregister_ip_vs_app(struct ip_vs_app *app)
 
 	up(&__ip_vs_app_mutex);
 
-	MOD_DEC_USE_COUNT;
+	/* decrease the module use count */
+	ip_vs_use_count_dec();
 }
 
 
