@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.33 2002/12/19 08:40:52 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.34 2003/05/10 03:05:23 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -711,7 +711,7 @@ ip_vs_out(unsigned int hooknum, struct sk_buff **skb_p,
 			}
 		}
 		IP_VS_DBG_PKT(12, pp, iph,
-			"packet continues traversal as normal");
+			      "packet continues traversal as normal");
 		if (!pp->dont_defrag)
 			ip_send_check(iph);
 		return NF_ACCEPT;
@@ -775,8 +775,8 @@ ip_vs_out(unsigned int hooknum, struct sk_buff **skb_p,
  *      Called by ip_fw_compact to detect packets for VS/NAT before
  *      they are changed by ipchains masquerading code.
  */
-unsigned int check_for_ip_vs_out(struct sk_buff **skb_p,
-				 int (*okfn)(struct sk_buff *))
+unsigned int
+check_for_ip_vs_out(struct sk_buff **skb_p, int (*okfn)(struct sk_buff *))
 {
 	unsigned int ret;
 
@@ -892,11 +892,10 @@ static int ip_vs_in_icmp(struct sk_buff **skb_p, int *related)
  *	Check if it's for virtual services, look it up,
  *	and send it on its way...
  */
-static unsigned int ip_vs_in(unsigned int hooknum,
-			     struct sk_buff **skb_p,
-			     const struct net_device *in,
-			     const struct net_device *out,
-			     int (*okfn)(struct sk_buff *))
+static unsigned int
+ip_vs_in(unsigned int hooknum, struct sk_buff **skb_p,
+	 const struct net_device *in, const struct net_device *out,
+	 int (*okfn)(struct sk_buff *))
 {
 	struct sk_buff	*skb = *skb_p;
 	struct iphdr	*iph = skb->nh.iph;
@@ -1018,11 +1017,10 @@ static unsigned int ip_vs_in(unsigned int hooknum,
  *      sent to ip_vs_in_icmp. So, catch them at the NF_IP_FORWARD chain
  *      and send them to ip_vs_in_icmp.
  */
-static unsigned int ip_vs_forward_icmp(unsigned int hooknum,
-				       struct sk_buff **skb_p,
-				       const struct net_device *in,
-				       const struct net_device *out,
-				       int (*okfn)(struct sk_buff *))
+static unsigned int
+ip_vs_forward_icmp(unsigned int hooknum, struct sk_buff **skb_p,
+		   const struct net_device *in, const struct net_device *out,
+		   int (*okfn)(struct sk_buff *))
 {
 	struct sk_buff	*skb = *skb_p;
 	struct iphdr	*iph = skb->nh.iph;
@@ -1046,27 +1044,39 @@ static unsigned int ip_vs_forward_icmp(unsigned int hooknum,
    or VS/NAT(change destination), so that filtering rules can be
    applied to IPVS. */
 static struct nf_hook_ops ip_vs_in_ops = {
-	{ NULL, NULL },
-	ip_vs_in, PF_INET, NF_IP_LOCAL_IN, 100
+	.hook		= ip_vs_in,
+	.owner		= THIS_MODULE,
+	.pf		= PF_INET,
+	.hooknum        = NF_IP_LOCAL_IN,
+	.priority       = 100,
 };
 
 /* After packet filtering, change source only for VS/NAT */
 static struct nf_hook_ops ip_vs_out_ops = {
-	{ NULL, NULL },
-	ip_vs_out, PF_INET, NF_IP_FORWARD, 100
+	.hook		= ip_vs_out,
+	.owner		= THIS_MODULE,
+	.pf		= PF_INET,
+	.hooknum        = NF_IP_FORWARD,
+	.priority       = 100,
 };
 
 /* After packet filtering (but before ip_vs_out_icmp), catch icmp
    destined for 0.0.0.0/0, which is for incoming IPVS connections */
 static struct nf_hook_ops ip_vs_forward_icmp_ops = {
-	{ NULL, NULL },
-	ip_vs_forward_icmp, PF_INET, NF_IP_FORWARD, 99
+	.hook		= ip_vs_forward_icmp,
+	.owner		= THIS_MODULE,
+	.pf		= PF_INET,
+	.hooknum        = NF_IP_FORWARD,
+	.priority       = 99,
 };
 
 /* Before the netfilter connection tracking, exit from POST_ROUTING */
 static struct nf_hook_ops ip_vs_post_routing_ops = {
-	{ NULL, NULL },
-	ip_vs_post_routing, PF_INET, NF_IP_POST_ROUTING, NF_IP_PRI_NAT_SRC-1
+	.hook		= ip_vs_post_routing,
+	.owner		= THIS_MODULE,
+	.pf		= PF_INET,
+	.hooknum        = NF_IP_POST_ROUTING,
+	.priority       = NF_IP_PRI_NAT_SRC-1,
 };
 
 
